@@ -1,4 +1,4 @@
-/*
+    /*
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation; either version 2
@@ -15,31 +15,27 @@
     Boston, MA  02110-1301, USA.
 
     ---
-    Copyright (C) 2012 Filipe Saraiva <filipe@kde.org>
+    Copyright (C) 2014, 2015 Minh Ngo <minh@fedoraproject.org>
  */
 
 #ifndef _PYTHON2BACKEND_H
 #define _PYTHON2BACKEND_H
 
-#include "backend.h"
+#include "../python/pythonbackend.h"
 
-class Python2Backend : public Cantor::Backend
+class Python2Backend : public PythonBackend
 {
   Q_OBJECT
   public:
-    explicit Python2Backend( QObject* parent = 0,const QList<QVariant> args = QList<QVariant>());
-    ~Python2Backend();
+    explicit Python2Backend(QObject* parent = nullptr, const QList<QVariant> args = QList<QVariant>());
+
+    Cantor::Session* createSession();
 
     QString id() const;
-    Cantor::Session *createSession();
-    Cantor::Backend::Capabilities capabilities() const;
-
-    QWidget* settingsWidget(QWidget* parent) const;
-    KConfigSkeleton* config() const;
-
     KUrl helpUrl() const;
     QString description() const;
+
+    KConfigSkeleton* config() const;
 };
 
-
-#endif /* _PYTHON2BACKEND_H */
+#endif
\ No newline at end of file
